@@ -10,7 +10,7 @@ see http://www.web2ldap.de for details
 
 Comprehensive list initially contributed by Norbert Klasen
 
-$Id: ldapoidreg.py,v 1.93 2012/06/01 20:56:22 michael Exp $
+$Id: ldapoidreg.py,v 1.94 2012/12/17 20:52:57 michael Exp $
 """
 
 oid_list = (
@@ -998,6 +998,11 @@ oid_list = (
     u"What Failed? Control",
     u"",
     u"draft-masarati-ldap-whatfailed"),
+  # see http://www.openldap.org/its/index.cgi?findid=6598
+  ("1.3.6.1.4.1.4203.666.5.18",
+    u"No-Op Search Control",
+    u"",
+    u"OpenLDAP ITS#6598"),
 
   # OpenLDAP's ldap.h: LDAP Experimental (works in progress) Features
   ("1.3.6.1.4.1.4203.666.8.2",
