@@ -11,7 +11,7 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: addmodifyform.py,v 1.283 2012/08/11 14:40:12 michael Exp $
+$Id: addmodifyform.py,v 1.284 2012/10/28 13:28:52 michael Exp $
 """
 
 import re,msbase,pyweblib,ldap,ldif,ldap.schema,\
@@ -538,7 +538,10 @@ def ReadLDIFTemplate(ls,template_name):
   if not addform_entry_templates.has_key(template_name):
     raise w2lapp.core.ErrorExit(u'LDIF template key not known.')
   ldif_file_name = addform_entry_templates[template_name]
-  ldif_file = open(ldif_file_name,'r')
+  try:
+    ldif_file = open(ldif_file_name,'r')
+  except (IOError,ValueError):
+    raise w2lapp.core.ErrorExit(u'Error opening LDIF template.')
   try:
     ldif_parser = ldif.LDIFRecordList(
       ldif_file,
@@ -548,7 +551,7 @@ def ReadLDIFTemplate(ls,template_name):
     )
     ldif_parser.parse()
   except (IOError,ValueError):
-    raise w2lapp.core.ErrorExit(u'Error reading LDIF template.')
+    raise w2lapp.core.ErrorExit(u'Error reading/parsing LDIF template.')
   if ldif_parser.all_records:
     dn,entry = ldif_parser.all_records[0]
   else:
