@@ -11,7 +11,7 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: form.py,v 1.118 2012/06/17 12:19:00 michael Exp $
+$Id: form.py,v 1.121 2012/12/17 20:36:45 michael Exp $
 """
 
 import urllib,codecs,re,ldif,ldapurl,ldap.schema,msgzip,ldaputil.base, \
@@ -239,7 +239,7 @@ class Web2LDAPForm_searchform(Web2LDAPForm):
     self.addField(pyweblib.forms.Input('search_attr',u'Attribute(s) to be searched',1000,w2lapp.cnf.misc.max_searchparams,ur'[\w,_;-]+'))
     self.addField(pyweblib.forms.Select('search_option',u'Search option',w2lapp.cnf.misc.max_searchparams,options=w2lapp.searchform.search_options))
     self.addField(pyweblib.forms.Input('search_string',u'Search string',100,w2lapp.cnf.misc.max_searchparams,u'.*',size=50))
-    self.addField(pyweblib.forms.Input('search_attrs',u'Attributes to be read',1000,1,ur'[*+\w,_;-]+'))
+    self.addField(pyweblib.forms.Input('search_attrs',u'Attributes to be read',1000,1,ur'[@*+0-9.\w,_;-]+'))
 
 class Web2LDAPForm_search(Web2LDAPForm_searchform):
   def addCommandFields(self):
@@ -399,6 +399,7 @@ class Web2LDAPForm_passwd(Web2LDAPForm):
     self.addField(pyweblib.forms.Checkbox('passwd_ntpasswordsync',u'Sync ntPassword for Samba',1,default="yes",checked=1))
     self.addField(pyweblib.forms.Checkbox('passwd_settimesync',u'Sync password setting times',1,default="yes",checked=1))
     self.addField(pyweblib.forms.Checkbox('passwd_forcechange',u'Force password change',1,default="yes",checked=0))
+    self.addField(pyweblib.forms.Checkbox('passwd_inform',u'Password change inform action',1,default="display_url",checked=0))
 
 class Web2LDAPForm_read(Web2LDAPForm):
   def addCommandFields(self):
@@ -409,7 +410,7 @@ class Web2LDAPForm_read(Web2LDAPForm):
     self.addField(pyweblib.forms.Input('read_attrindex',u'Read attribute',255,1,u'[0-9]+'))
     self.addField(pyweblib.forms.Input('read_attrmimetype',u'MIME type',255,1,u'[\w.-]+/[\w.-]+'))
     self.addField(pyweblib.forms.Select('read_output',u'Read output format',1,options=['table','vcard','template'],default='template'))
-    self.addField(pyweblib.forms.Input('search_attrs',u'Attributes to be read',1000,1,ur'[*+\w,_;-]+'))
+    self.addField(pyweblib.forms.Input('search_attrs',u'Attributes to be read',1000,1,ur'[@*+0-9.\w,_;-]+'))
     self.addField(pyweblib.forms.Input('read_expandattr',u'Attributes to be read',1000,1,ur'[*+\w,_;-]+'))
 
 class Web2LDAPForm_groupadm(Web2LDAPForm):
