@@ -11,7 +11,7 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: gui.py,v 1.265 2012/08/25 14:09:57 michael Exp $
+$Id: gui.py,v 1.274 2012/12/12 21:11:24 michael Exp $
 """
 
 import os,urllib,ldap, \
@@ -24,6 +24,8 @@ from pyweblib.forms import escapeHTML
 
 from ldaputil.base import ParentDN,ParentDNList,explode_dn
 
+from msbase import GrabKeys
+
 from types import UnicodeType
 
 ########################################################################
@@ -67,7 +69,7 @@ def ReadTemplate(form,ls,config_key,form_desc=u'',tmpl_filename=None):
   return tmpl_str # ReadTemplate()
 
 
-def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
+def LDAPError2ErrMsg(e,form,charset='utf-8',template='{error_msg}<br>{matched_dn}'):
   """
   Converts a LDAPError exception into HTML error message
 
@@ -131,9 +133,20 @@ def LDAPError2ErrMsg(e,form,charset='utf-8',template=r'%s'):
         matched_dn = unicode(e.args[0].get('matched',''),charset)
       except KeyError:
         matched_dn = None
+
   ErrMsg = ErrMsg.replace(u'\r','').replace(u'\t','')
   ErrMsg_html = form.utf2display(ErrMsg,lf_entity='<br>')
-  return template % ErrMsg_html
+
+  # Add matchedDN to error message HTML if needed
+  if matched_dn:
+    matched_dn_html = '<br>Matched DN: %s' % (form.utf2display(matched_dn.decode(charset)))
+  else:
+    matched_dn_html = ''
+
+  return template.format(
+    error_msg=ErrMsg_html,
+    matched_dn=matched_dn_html
+  )
 
 
 def DisplayDN(sid,form,ls,dn,commandbutton=0,active_ldapurl=0,bindas_button=False):
@@ -280,51 +293,73 @@ def ContextMenuSingleEntry(sid,form,ls,dn,vcard_link=0,dds_link=0,entry_uuid=Non
   return result # ContextMenuSingleEntry()
 
 
+def WhoAmITemplate(sid,outf,form,ls,dn,who=None,entry=None):
+  if who==None:
+    if hasattr(ls,'who') and ls.who:
+      who = ls.who
+      entry = ls.userEntry
+    else:
+      return 'anonymous'
+  # Determine relevant templates dict
+  bound_as_templates = ldap.cidict.cidict(w2lapp.cnf.GetParam(
+    ls.ldapUrl(ls.getSearchRoot(who)),'boundas_template',{}
+  ))
+  # Read entry if necessary
+  if entry==None:
+    read_attrs = set(['objectClass'])
+    for oc in bound_as_templates.keys():
+      read_attrs.update(GrabKeys(bound_as_templates[oc]).keys)
+    try:
+      ldap_result = ls.readEntry(who,attrtype_list=list(read_attrs))
+    except ldap.LDAPError,e:
+      entry = {}
+    else:
+      if ldap_result:
+        _,entry = ldap_result[0]
+      else:
+        entry = {}
+  if ldaputil.base.is_dn(who):
+    if entry:
+      sub_schema = ls.retrieveSubSchema(who,w2lapp.cnf.GetParam(ls,'_schema',None))
+      user_entry_display_dict = msbase.CaseinsensitiveStringKeyDict(
+        default_dict=dict([
+          (
+            attr_type.lower(),
+            w2lapp.gui.DataStr(sid,form,ls,dn,sub_schema,attr_type,attr_values[0],commandbutton=0)
+          )
+          for attr_type,attr_values in entry.items()
+        ]),
+        default='',
+      )
+      try:
+        user_object_classes = [ oc.lower() for oc in entry['objectClass'] ]
+      except KeyError:
+        result = DisplayDN(sid,form,ls,who,commandbutton=0,active_ldapurl=0,bindas_button=False)
+      else:
+        bound_as_templates = ldap.cidict.cidict(w2lapp.cnf.GetParam(
+          ls.ldapUrl(ls.getSearchRoot(who)),'boundas_template',{}
+        ))
+        for oc in user_object_classes:
+          try:
+            result = bound_as_templates[oc] % user_entry_display_dict
+          except KeyError:
+            pass
+          else:
+            break
+        else:
+          result = DisplayDN(sid,form,ls,who,commandbutton=0,active_ldapurl=0,bindas_button=False)
+    else:
+      result = DisplayDN(sid,form,ls,who,commandbutton=0,active_ldapurl=0,bindas_button=False)
+  else:
+    result = form.utf2display(who)
+  return result # WhoAmITemplate()
+
+
 def StatusLine(sid,outf,form,ls,dn,who_templates=None):
   """
   Status line displaying host, current DN, LDAP URL and bind DN
   """
 
-  def WhoAmITemplate(sid,outf,form,ls,dn):
-    if hasattr(ls,'who') and ls.who:
-      if ldaputil.base.is_dn(ls.who):
-        if ls.userEntry:
-          sub_schema = ls.retrieveSubSchema(ls.who,w2lapp.cnf.GetParam(ls,'_schema',None))
-          user_entry_display_dict = msbase.CaseinsensitiveStringKeyDict(
-            default_dict=dict([
-              (
-                attr_type.lower(),
-                w2lapp.gui.DataStr(sid,form,ls,dn,sub_schema,attr_type,attr_values[0],commandbutton=0)
-              )
-              for attr_type,attr_values in ls.userEntry.items()
-            ]),
-            default='',
-          )
-          try:
-            user_object_classes = [ oc.lower() for oc in ls.userEntry['objectClass'] ]
-          except KeyError:
-            result = DisplayDN(sid,form,ls,ls.who,commandbutton=0,active_ldapurl=0,bindas_button=False)
-          else:       
-            bound_as_templates = ldap.cidict.cidict(w2lapp.cnf.GetParam(
-              ls.ldapUrl(ls.getSearchRoot(ls.who)),'boundas_template',{}
-            ))
-            for oc in user_object_classes:
-              try:
-                result = bound_as_templates[oc] % user_entry_display_dict
-              except KeyError:
-                pass
-              else:
-                break
-            else:
-              result = DisplayDN(sid,form,ls,ls.who,commandbutton=0,active_ldapurl=0,bindas_button=False)
-        else:
-          result = DisplayDN(sid,form,ls,ls.who,commandbutton=0,active_ldapurl=0,bindas_button=False)
-      else:
-        result = form.utf2display(ls.who)
-    else:
-      result = 'anonymous'
-    return result # WhoAmITemplate()
-
   status_template_str = w2lapp.gui.ReadTemplate(form,ls,'status_template',u'status section')
 
   template_dict = {
@@ -440,8 +475,14 @@ def DITNavigationList(sid,outf,form,ls,dn,level=0):
 def TopSection(sid,outf,form,ls,dn,title,main_menu_list,context_menu_list=[]):
   if not dn or not ldaputil.base.is_dn(dn):
     dn=u''
+  if ls:
+    uri = (ls.uri or '').decode('ascii')
+  else:
+    uri = u''
   web2ldap_title = ' - '.join(filter(None,[
-    form.utf2display(dn),title
+    form.utf2display(uri),
+    form.utf2display(dn),
+    title
   ]))
   w2lapp.gui.PrintHeader(sid,outf,form,web2ldap_title,w2lapp.cnf.GetParam(ls,'link_css',''))
   outf.write('<div id="TopSection">\n')
@@ -466,7 +507,7 @@ def SimpleMessage(
 
 # Return a pretty HTML-formatted string describing a schema element
 # referenced by name or OID
-def SchemaElementName(sid,form,dn,schema,se_nameoroid,se_class,name_template=r'<strong>%s</strong>'):
+def SchemaElementName(sid,form,dn,schema,se_nameoroid,se_class,name_template=r'%s'):
   result = [name_template % (se_nameoroid.encode())]
   if se_class:
     se = schema.get_obj(se_class,se_nameoroid,None)
@@ -543,11 +584,13 @@ def PrintHeader(sid,outf,form,TitleMsg,link_css):
   html_begin_template_str = open(html_begin_template_filename,'rb').read()
   outf.write(html_begin_template_str.format(
     title_msg=TitleMsg.replace('<br>',''),
+    refresh_time=str(w2lapp.cnf.misc.session_remove+10),
+    base_url=form.script_name,
     web2ldap_version=w2lapp.__version__,
     accept_charset=form.accept_charset,
     link_css=link_css,
   ))
-  return
+  return # PrintHeader()
 
 
 # Ausdrucken eines HTML-Endes
