@@ -10,12 +10,12 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: handler.py,v 1.306 2012/05/05 20:50:07 michael Exp $
+$Id: handler.py,v 1.311 2012/12/12 21:11:24 michael Exp $
 """
 
 NON_INTERACTIVE_LOGIN_MECHS = set(['EXTERNAL','GSSAPI'])
 
-import sys,types,socket,errno,\
+import sys,types,socket,errno,time,\
        ldap,ldaputil,ldaputil.dns,ldapsession,mssignals, \
        pyweblib.forms,pyweblib.httphelper,pyweblib.sslenv,pyweblib.helper,pyweblib.session
 
@@ -126,6 +126,8 @@ def ExtractPathInfo(env):
 
 def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
 
+  current_access_time = time.time()
+
   ls = None
 
   ####################################################
@@ -207,6 +209,12 @@ def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
         # Session ID given => try to restore old session
         #################################################
 
+        try:
+          last_session_timestamp,_ = session.sessiondict[sid]
+        except KeyError:
+          # will be handled later on...
+          pass
+
         try:
           ls = session.retrieveSession(sid,env)
         except pyweblib.session.SessionExpired,e:
@@ -227,7 +235,9 @@ def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
           if not isinstance(ls,LDAPSession):
             pyweblib.httphelper.URLRedirect(outf,form.script_name,2,'Session not properly initialized.')
             return
-          if w2lapp.cnf.misc.session_paranoid:
+          if w2lapp.cnf.misc.session_paranoid and \
+             current_access_time-last_session_timestamp>w2lapp.cnf.misc.session_paranoid:
+            # Store session with new session ID
             sid = session.renameSession(sid,env)
 
       else:
@@ -459,7 +469,7 @@ def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
         ls.getRootDSE()
 
       ls.setDN(dn)
-        
+
       # Check for valid LDAPSession and connection to provide reasonable
       # error message instead of logging exception in case user is playing
       # with manually generated URLs
@@ -526,7 +536,10 @@ def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
           new_dn = dn
         ExceptionMsg(
           sid,outf,form,ls,new_dn,u'No such object',
-          '\n'.join((w2lapp.gui.LDAPError2ErrMsg(e,form,ls.charset),w2lapp.gui.DisplayDN(sid,form,ls,dn)))
+          w2lapp.gui.LDAPError2ErrMsg(
+            e,form,ls.charset,
+            template='{error_msg}<br>%s<br>{matched_dn}' % (w2lapp.gui.DisplayDN(sid,form,ls,dn))
+          )
         )
       else:
         # Found LDAP server for this naming context via DNS SRV RR
@@ -552,6 +565,12 @@ def HandleHTTPRequest(inf,outfile,errfile,env,script_name=None):
       )
 
     except ldapsession.PasswordPolicyException,e:
+      # Setup what's required to the case command=='passwd'
+      ls.setDN(dn or e.who)
+      form.addField(pyweblib.forms.Select('passwd_scheme',u'Password hash scheme',1,options=w2lapp.passwd.available_hashtypes,default=w2lapp.passwd.available_hashtypes[-1]))
+      form.addField(pyweblib.forms.Checkbox('passwd_ntpasswordsync',u'Sync ntPassword for Samba',1,default="yes",checked=1))
+      form.addField(pyweblib.forms.Checkbox('passwd_settimesync',u'Sync password setting times',1,default="yes",checked=1))
+      # Directly generate the change password form
       w2lapp.passwd.PasswdForm(
         sid,outf,command,form,ls,dn,None,
         None,e.who.decode(ls.charset),None,
