@@ -2,12 +2,14 @@
 """
 web2ldap plugin classes for OpenDS and OpenDJ
 
-$Id: opends.py,v 1.27 2012/05/31 17:15:33 michael Exp $
+$Id: opends.py,v 1.29 2012/11/16 23:06:19 michael Exp $
 """
 
-import re,mspki.util,w2lapp.schema
+import re,mspki.util,ldap,ldap.cidict,w2lapp.schema
 
-from w2lapp.schema.syntaxes import LDAPSyntax,DirectoryString,OctetString,SelectList,DynamicDNSelectList,MultilineText,Certificate,syntax_registry
+from w2lapp.schema.syntaxes import LDAPSyntax,DirectoryString,OctetString,SelectList,DynamicDNSelectList,MultilineText,Certificate,BindDN,syntax_registry
+
+from ldaputil.base import explode_dn,rdn_dict
 
 
 class OpenDSCfgPasswordPolicy(DynamicDNSelectList):
@@ -393,6 +395,44 @@ syntax_registry.registerAttrType(
 )
 
 
+class OpenDSdsCfgAlternatebindDn(BindDN):
+  oid = 'OpenDSdsCfgAlternatebindDn-oid'
+  desc = 'OpenDS/OpenDJ alternative bind DN'
+
+  def formValue(self):
+    if not self.attrValue:
+      return u''
+    entry = ldap.cidict.cidict(self._entry)
+    attr_value = self.attrValue.decode(self._ls.charset)
+    try:
+      dn_comp_list = explode_dn(attr_value)
+    except ldap.DECODING_ERROR:
+      result = BindDN.formValue(self)
+    else:
+      try:
+        rdn = rdn_dict(dn_comp_list[0])
+      except ldap.DECODING_ERROR:
+        result = BindDN.formValue(self)
+      else:
+        new_rdn = u'+'.join([
+          u'='.join((
+            rdn_attr,
+            rdn_value[0] or entry.get(rdn_attr,[u''])[0]
+          ))
+          for rdn_attr,rdn_value in rdn.items()
+        ])
+        new_dn_comp_list = [new_rdn]
+        new_dn_comp_list.extend(dn_comp_list[1:])
+        result = u','.join(new_dn_comp_list)
+    return result
+
+syntax_registry.registerAttrType(
+  OpenDSdsCfgAlternatebindDn.oid,[
+    '1.3.6.1.4.1.26027.1.1.13', # ds-cfg-alternate-bind-dn
+  ]
+)
+
+
 # cn=changelog
 #------------------------
 
