@@ -11,24 +11,25 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: search.py,v 1.215 2012/08/05 16:20:11 michael Exp $
+$Id: search.py,v 1.221 2013/01/02 17:47:47 michael Exp $
 """
 
 import time,csv,urllib,ldap,ldap.schema.models,ldap.async,dsml, \
-       msbase,pyweblib.forms,pyweblib.httphelper,ldaputil.base, \
+       msbase,pyweblib.forms,pyweblib.httphelper,ldaputil.base,ldaputil.schema, \
        w2lapp.core,w2lapp.cnf,w2lapp.gui,w2lapp.searchform
 
 
 from ldapurl import LDAPUrl
 from msbase import GrabKeys
 from w2lapp.schema.syntaxes import syntax_registry
+from ldaputil.controls import SearchNoOpControl
 
 SizeLimitMsg = """
 <p class="ErrorMessage">
   <strong>
     Only partial results received. Try to refine search.
   </strong><br>
-  %s
+  {error_msg}
 </p>
 """
 
@@ -64,7 +65,7 @@ class CSVWriter(ldap.async.AsyncSearchHandler):
 
   def _processSingleResult(self,resultType,resultItem):
     if self._entryResultTypes.has_key(resultType):
-      entry = ldap.schema.models.Entry(self._s,resultItem[0],resultItem[1])
+      entry = ldaputil.schema.Entry(self._s,resultItem[0],resultItem[1])
       csv_row_list = []
       for attr_type in self._attr_types:
         csv_col_value_list = []
@@ -111,7 +112,7 @@ else:
 
     def _processSingleResult(self,resultType,resultItem):
       if self._entryResultTypes.has_key(resultType):
-        entry = ldap.schema.models.Entry(self._s,resultItem[0],resultItem[1])
+        entry = ldaputil.schema.Entry(self._s,resultItem[0],resultItem[1])
         csv_row_list = []
         for attr_type in self._attr_types:
           csv_col_value_list = []
@@ -267,6 +268,9 @@ def w2l_Search(sid,outf,command,form,ls,dn,connLDAPUrl):
     if a.strip()
   ]
 
+  search_attr_set = ldaputil.schema.SchemaElementOIDSet(sub_schema,ldap.schema.models.AttributeType,search_attrs)
+  search_attrs = search_attr_set.names()
+
   if search_output=='print':
     print_template_filenames_dict = w2lapp.cnf.GetParam(ls,'print_template',None)
     print_cols = w2lapp.cnf.GetParam(ls,'print_cols','4')
@@ -378,7 +382,8 @@ def w2l_Search(sid,outf,command,form,ls,dn,connLDAPUrl):
   if search_output in ['table','raw']:
 
     SearchWarningMsg = ''
-    partial_results = 0
+    max_result_msg = ''
+    num_all_search_results,num_all_search_continuations = None,None
 
     try:
       result_handler.processResults(
@@ -388,6 +393,24 @@ def w2l_Search(sid,outf,command,form,ls,dn,connLDAPUrl):
       if search_size_limit<0 or result_handler.endResultBreak<search_size_limit:
         SearchWarningMsg = w2lapp.gui.LDAPError2ErrMsg(e,form,ls.charset,template=SizeLimitMsg)
       partial_results = 1
+      # Retrieve the overall number of search results by resending the
+      # search request without size limit but with the SearchNoOpControl attached
+      if SearchNoOpControl.controlType in ls.rootDSE.get('supportedControl',[]):
+        msg_id = ls.l.search_ext(
+          search_root.encode(ls.charset),
+          scope,
+          filterstr=filterstr2.encode(ls.charset),
+          attrlist=['1.1'],
+          serverctrls=[SearchNoOpControl()],
+        )
+        _,_,_,search_response_ctrls = ls.l.result3(msg_id,all=1)
+        noop_srch_ctrl = [
+          c
+          for c in search_response_ctrls
+          if c.controlType==SearchNoOpControl.controlType
+        ]
+        if noop_srch_ctrl:
+          _,num_all_search_results,num_all_search_continuations = noop_srch_ctrl[0].resultCode,noop_srch_ctrl[0].numSearchResults,noop_srch_ctrl[0].numSearchContinuations
     except (ldap.FILTER_ERROR,ldap.INAPPROPRIATE_MATCHING),e:
       # Give the user a chance to edit his bad search filter
       w2lapp.searchform.w2l_SearchForm(
@@ -401,6 +424,8 @@ def w2l_Search(sid,outf,command,form,ls,dn,connLDAPUrl):
       partial_results = 0
       if dn or scope!=ldap.SCOPE_ONELEVEL:
         raise e
+    else:
+      partial_results = 0
 
     search_resminindex = result_handler.beginResultsDropped
     resind = result_handler.endResultBreak
@@ -490,10 +515,13 @@ def w2l_Search(sid,outf,command,form,ls,dn,connLDAPUrl):
               title=u'Display all search results at once',
             )
           )
+          if num_all_search_results!=None:
+            max_result_msg = '(of %d) ' % (num_all_search_results)
 
-        result_message = 'Results %d - %d of %s search below %s with filter &quot;%s&quot;.' % (
+        result_message = 'Results %d - %d %sof %s search below %s with filter &quot;%s&quot;.' % (
             search_resminindex+1,
             resind,
+            max_result_msg,
             ldaputil.base.SEARCH_SCOPE_STR[scope],
             utf2display(search_root),
             utf2display(filterstr2),
